@@ -6,22 +6,47 @@ use strict;
 use WWW::AUR::UserAgent qw();
 use WWW::AUR::Package   qw();
 use WWW::AUR::URI       qw( pkg_uri );
-use WWW::AUR            qw( _category_name );
+use WWW::AUR            qw( _path_params _category_name );
 
 my $PKGID_MATCH = qr{ <td .*? </td> \s*
-                      <td .*? </td> \s*
                       <td .*? >
                       <span [ ] class='f4'>
                       <a [ ] href='packages[.]php[?]ID=(\d+)'> }xms;
 
 sub new
 {
-    my $class  = shift;
-    my $self   = bless { @_ }, $class;
+    my $class = shift;
+    my $self  = bless {}, $class;
+    $self->init( @_ );
+}
+
+sub init
+{
+    my $self = shift;
+
+    my $startidx;
+    $startidx = shift if @_ % 2 == 1;
+
+    %$self = ( %$self, _path_params( @_ ));
     $self->reset();
+    $self->set_pos( $startidx ) if $startidx;
+
     return $self;
 }
 
+sub set_pos
+{
+    my ($self, $startidx) = @_;
+    Carp::croak 'Argument to set_pos() must an integer'
+        unless $startidx =~ /\A\d+\z/;
+
+    $self->{'curridx'}  = $startidx;
+    $self->{'finished'} = 0;
+    $self->{'packages'} = [];
+
+    return;
+}
+
 sub reset
 {
     my ($self) = @_;
@@ -45,9 +70,9 @@ sub _scrape_pkglist
 {
     my ($self) = @_;
 
-    my $uri  = _pkglist_uri( $self->{curridx} );
-    my $resp = $self->{useragent}->get( $uri );
-    
+    my $uri  = _pkglist_uri( $self->{'curridx'} );
+    my $resp = $self->{'useragent'}->get( $uri );
+
     Carp::croak 'Failed to GET package list webpage: ' . $resp->status_line
         unless $resp->is_success;
 
@@ -135,19 +160,24 @@ WWW::AUR::Iterator - An iterator for looping through all AUR packages.
 
   my $aurobj = WWW:AUR->new();
   my $iter = $aurobj->iter();
-
+  
   # or without WWW::AUR:
   my $iter = WWW::AUR::Iterator->new();
-
+  
   while ( my $pkg = $iter->next_obj ) {
       print $pkg->name, "\n";
   }
-
+  
   $iter->reset;
   while ( my $p = $iter->next ) {
-      print "$_:$p->{$_}\n" for qw{ id name version category desc maintainer };
+      print "$_:$p->{$_}\n"
+          for qw{ id name version category desc maintainer };
       print "---\n";
   }
+  
+  # Retrieve information on the 12,345th package, alphabetically.
+  $iter->set_pos(12_345);
+  my $pkginfo  = $iter->next;
 
 =head1 DESCRIPTION
 
@@ -234,6 +264,21 @@ If we have iterated through all packages, then C<undef> is returned.
 
 =back
 
+=head2 set_pos
+
+  undef = $OBJ->set_pos( $POS );
+
+Set the iterator position to the given index in the entire list of
+packages from packages.php.
+
+=over 4
+
+=item C<$POS>
+
+This is not the package ID but simply the list offset on the package webpage.
+
+=back
+
 =head1 SEE ALSO
 
 L<WWW::AUR>
